<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>Couldn&apos;t initialize QSql driver!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t open mySQL connection!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Tous</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid SQL or failed DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="unfinished">Panneau</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NPR/DS SoundExchange Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classical Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NaturalLog Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WideOrbit Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel First Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition/Cue Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 2 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Second Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Third Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fourth Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fifth and Later Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reserved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mr. Master Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spin Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>promo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NoTime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MusicLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TrafficLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>host already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>service already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>template service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>template host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No such service!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No such group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No free cart available in group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddCart</name>
    <message>
        <source>&amp;Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Cart Number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Cart Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Cart Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>No Available Cart Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are no more available cart numbers for the group!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Cart Number!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must enter a cart title!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The cart number is outside of the permitted range for this group!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart already exists.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddLog</name>
    <message>
        <source>Create Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Log Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The service is invalid!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAudioSettingsDialog</name>
    <message>
        <source>Edit Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default &amp;Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default &amp;Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default &amp;Sample Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default &amp;Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDButtonDialog</name>
    <message>
        <source>Edit Button</source>
        <translation>Modifier Bouton</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Label :</translation>
    </message>
    <message>
        <source>Cart:</source>
        <translation>Cart :</translation>
    </message>
    <message>
        <source>Set
Cart</source>
        <translation>Choisir
Le Cart</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Set
Color</source>
        <translation>Choisir
La Couleur</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>NOT FOUND</source>
        <translation>NON TROUVE</translation>
    </message>
</context>
<context>
    <name>RDCardSelector</name>
    <message>
        <source>Card:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCartDialog</name>
    <message>
        <source>Select Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER DEF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>END</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to
&amp;Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COMPOSER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CONDUCTOR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary cart for import!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported from</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEdit</name>
    <message>
        <source>&amp;Audition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Début</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>&amp;Recue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEditDialog</name>
    <message>
        <source>Set Cue Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>RDCutDialog</name>
    <message>
        <source>Select Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add New
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDDateDialog</name>
    <message>
        <source>Select Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>RDDatePicker</name>
    <message>
        <source>Mo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Th</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Su</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDEditAudio</name>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>Amplitude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom
In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom
Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full
In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full
Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Goto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Fin</translation>
    </message>
    <message>
        <source>Cut
Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut
End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk
Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue
Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue
End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fade
Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook
Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook
End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Threshold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trim
Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trim
End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Gain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove
Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Talk Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Segue Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Hook Markers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Fade Up Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Fade Down Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;none&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fade Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fade Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rivendell Web Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to download peak data, error was:
&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Less than half of the audio is playable with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More than half of the audio will be faded with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDEditPanelName</name>
    <message>
        <source>Edit Panel Name</source>
        <translation>Modifier le Nom du Panneau</translation>
    </message>
    <message>
        <source>Panel &amp;Name:</source>
        <translation>&amp;Nom :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>RDExceptionDialog</name>
    <message>
        <source>Rivendell Exception Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text (*.txt *.TXT)
All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already exists!
Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>for writing!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDExportSettingsDialog</name>
    <message>
        <source>Edit Export Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Sample Rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Bitrate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VBR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>32 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>64 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>96 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>128 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>160 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>192 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>224 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>256 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>288 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>320 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>352 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>384 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>416 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>448 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>48 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>56 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>80 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>112 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>40 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>24 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>144 kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDGetAth</name>
    <message>
        <source>Enter ATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the agreggate tuning hours (ATH)
figure for the report period.
(Supplied by your streaming provider).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ATH:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>Invalid ATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must provide a valid ATH figure!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDGetPasswd</name>
    <message>
        <source>Enter Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>RDGpioSelector</name>
    <message>
        <source>Pin:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDImportAudio</name>
    <message>
        <source>Import/Export Audio File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import file metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export file metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Audio File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import complete!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected file already exists!
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export complete!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDIntegerDialog</name>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>Set Value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDIntegerEdit</name>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Value</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDLicense</name>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GNU Public License v2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDListGroups</name>
    <message>
        <source>Select Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>RDListLogs</name>
    <message>
        <source>NAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDListSelector</name>
    <message>
        <source>Available Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &gt;&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;&lt; Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Services</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDLogFilter</name>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Effacer</translation>
    </message>
    <message>
        <source>Show Only Recent Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDLogLine</name>
    <message>
        <source>Panel</source>
        <translation type="obsolete">Panneau</translation>
    </message>
</context>
<context>
    <name>RDPanelButton</name>
    <message>
        <source>No Audio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDPasswd</name>
    <message>
        <source>Change Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;onfirm:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Mismatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The passwords don&apos;t match,
please try again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDRehash</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDXport service returned an error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid user or password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDRenderer</name>
    <message>
        <source>no such cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no such cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using temporary file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 2 of 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 1 of 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pass 1 of 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>first-time event not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>last-time event not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FAIL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NO AUDIO AVAILABLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SKIP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unable to open output file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log render halted at line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>due to STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>failed to play (NO AUDIO AVAILABLE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendered log is too long!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDSoundPanel</name>
    <message>
        <source>Play All</source>
        <translation>Jouer tout</translation>
    </message>
    <message>
        <source>Play Hook</source>
        <translation>J. Marques</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Configurer</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cart</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation>Panneau</translation>
    </message>
</context>
<context>
    <name>RDSqlDatabaseStatus</name>
    <message>
        <source>Database connection restored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Database connection failed : </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDStereoMeter</name>
    <message>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLIP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDSvc</name>
    <message>
        <source>The following events were not placed:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[unknown cart]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Fill Errors
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log in use by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
